CREATE TABLE FB_ORDER_STATUS (
  ID_FB_ORDER_STATUS NUMBER NOT NULL,
  DESCRIPTION VARCHAR2(200 CHAR),
  ACTIVE VARCHAR2(1 CHAR),
  CONSTRAINT FB_ORDER_STATUS_PK PRIMARY KEY (ID_FB_ORDER_STATUS)
);

INSERT INTO FB_ORDER_STATUS(ID_FB_ORDER_STATUS, DESCRIPTION, ACTIVE) VALUES
(-10, 'Deleted', 'N');

INSERT INTO FB_ORDER_STATUS(ID_FB_ORDER_STATUS, DESCRIPTION, ACTIVE) VALUES
(-1, 'Cancelled', 'Y');

INSERT INTO FB_ORDER_STATUS(ID_FB_ORDER_STATUS, DESCRIPTION, ACTIVE) VALUES
(1, 'Open', 'Y');

CREATE SEQUENCE FB_ORDER_STATUS_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 20 NOCACHE NOORDER  NOCYCLE;

CREATE TABLE FB_ORDER (
  ID_FB_ORDER NUMBER NOT NULL,
  ID_FB_TABLE NUMBER,
  ID_LASTNIKA NUMBER,
  ID_STATUS NUMBER,
  ORDER_NUMBER VARCHAR2(20 CHAR),
  DATE_FROM DATE,
  DATE_TO DATE,
  "COMMENT" VARCHAR2(300 CHAR),
  DATE_CREATED DATE,
  USER_CREATED VARCHAR2(20 CHAR),
  CONSTRAINT FB_ORDER_PK PRIMARY KEY (ID_FB_ORDER),
  CONSTRAINT FB_ORDER_ID_FB_TABLE_FK FOREIGN KEY (ID_FB_TABLE) REFERENCES FB_TABLE(ID_FB_TABLE),
  CONSTRAINT FB_ORDER_ID_LASTNIKA_FK FOREIGN KEY (ID_LASTNIKA) REFERENCES KUPCI(ID),
  CONSTRAINT FB_ORDER_ID_STATUS_FK FOREIGN KEY (ID_STATUS) REFERENCES FB_ORDER_STATUS(ID_FB_ORDER_STATUS)
);

CREATE INDEX IX_FB_ORDER_ID_FB_TABLE ON FB_ORDER (ID_FB_TABLE);
CREATE INDEX IX_FB_ORDER_ID_LASTNIKA ON FB_ORDER (ID_LASTNIKA);
CREATE INDEX IX_FB_ORDER_ID_STATUS ON FB_ORDER (ID_STATUS);

CREATE SEQUENCE FB_ORDER_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;

CREATE TABLE FB_ORDER_DETAIL (
  ID_FB_ORDER_DETAIL NUMBER NOT NULL,
  ID_FB_ORDER NUMBER,
  ID_STATUS NUMBER,
  ID_ARTIKEL NUMBER,
  QUANTITY NUMBER,
  "COMMENT" VARCHAR2(300 CHAR),
  CONSTRAINT FB_ORDER_DETAIL_PK PRIMARY KEY (ID_FB_ORDER_DETAIL),
  CONSTRAINT FB_ORDER_DETAIL_ID_FB_ORDER_FK FOREIGN KEY (ID_FB_ORDER) REFERENCES FB_ORDER(ID_FB_ORDER),
  CONSTRAINT FB_ORDER_DETAIL_ID_STATUS_FK FOREIGN KEY (ID_STATUS) REFERENCES FB_ORDER_STATUS(ID_FB_ORDER_STATUS),
  CONSTRAINT FB_ORDER_DETAIL_ID_ARTIKEL_FK FOREIGN KEY (ID_ARTIKEL) REFERENCES S_ARTIKLI(ID_ARTIKEL)
);

CREATE INDEX IX_FB_ORDER_DETAIL_ID_FB_ORDER ON FB_ORDER_DETAIL (ID_FB_ORDER);
CREATE INDEX IX_FB_ORDER_DETAIL_ID_STATUS ON FB_ORDER_DETAIL (ID_STATUS);
CREATE INDEX IX_FB_ORDER_DETAIL_ID_ARTIKEL ON FB_ORDER_DETAIL (ID_ARTIKEL);

CREATE SEQUENCE FB_ORDER_DETAIL_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;

CREATE OR REPLACE VIEW V_FB_ORDER
AS (
SELECT FO.ID_FB_ORDER, FO.ORDER_NUMBER, FO.ID_FB_TABLE, FO.ID_LASTNIKA, FO.ID_STATUS, FO.DATE_FROM, FO.DATE_TO, FO."COMMENT", FO.DATE_CREATED, FO.USER_CREATED,
FT.ID_FB_LOCATION, FT.DESCRIPTION AS TABLE_DESCRIPTION, FL.DESCRIPTION AS AREA_DESCRIPTION, FOS.DESCRIPTION AS STATUS_DESCRIPTION, U.USER_ AS USER_NAME,
(CASE WHEN (SELECT VREDNOST FROM S_NASTAVITVE WHERE FILTER = 'MARINA' AND SEKCIJA = 'MARINA' AND NAZIV = 'ChangeFirstLastName') = '1' THEN (KUP.IME || ' ' || KUP.PRIIMEK) ELSE (KUP.PRIIMEK || ' ' || KUP.IME) END) AS OWNER
FROM FB_ORDER FO
LEFT OUTER JOIN FB_TABLE FT ON FT.ID_FB_TABLE = FO.ID_FB_TABLE
LEFT OUTER JOIN FB_LOCATION FL ON FL.ID_FB_LOCATION = FT.ID_FB_LOCATION
LEFT OUTER JOIN FB_ORDER_STATUS FOS ON FOS.ID_FB_ORDER_STATUS = FO.ID_STATUS
LEFT OUTER JOIN NUSER U ON U.NUSER = FO.USER_CREATED
LEFT OUTER JOIN KUPCI KUP ON KUP.ID = FO.ID_LASTNIKA
);

insert into verzije_baza
(id, dt_vpis, verzija, ver_nr, opis) values (1565, SYSDATE, '5.5', 1485, 'FB order')
;
